Struct TriePrefixSetsMut
pub struct TriePrefixSetsMut {
pub account_prefix_set: PrefixSetMut,
pub storage_prefix_sets: HashMap<FixedBytes<32>, PrefixSetMut, FbBuildHasher<32>>,
pub destroyed_accounts: HashSet<FixedBytes<32>, FbBuildHasher<32>>,
}Expand description
Collection of mutable prefix sets.
Fields
account_prefix_set: PrefixSetMutA set of account prefixes that have changed.
storage_prefix_sets: HashMap<FixedBytes<32>, PrefixSetMut, FbBuildHasher<32>>A map containing storage changes with the hashed address as key and a set of storage key prefixes as the value.
destroyed_accounts: HashSet<FixedBytes<32>, FbBuildHasher<32>>A set of hashed addresses of destroyed accounts.
Implementations
impl TriePrefixSetsMut
impl TriePrefixSetsMut
pub fn extend(&mut self, other: TriePrefixSetsMut)
pub fn extend(&mut self, other: TriePrefixSetsMut)
Extends prefix sets with contents of another prefix set.
pub fn extend_ref(&mut self, other: &TriePrefixSetsMut)
pub fn extend_ref(&mut self, other: &TriePrefixSetsMut)
Extends prefix sets with contents of another prefix set by reference.
pub fn freeze(self) -> TriePrefixSets
pub fn freeze(self) -> TriePrefixSets
Returns a TriePrefixSets with the same elements as these sets.
If not yet sorted, the elements will be sorted and deduplicated.
pub fn clear(&mut self)
pub fn clear(&mut self)
Clears the prefix sets and destroyed accounts map.