pub struct AccountProof {
pub address: Address,
pub info: Option<Account>,
pub proof: Vec<Bytes>,
pub storage_root: FixedBytes<32>,
pub storage_proofs: Vec<StorageProof>,
}Expand description
The merkle proof with the relevant account info.
Fields
address: AddressThe address associated with the account.
info: Option<Account>Account info, if any.
proof: Vec<Bytes>Array of rlp-serialized merkle trie nodes which starting from the root node and following the path of the hashed address as key.
storage_root: FixedBytes<32>The storage trie root.
storage_proofs: Vec<StorageProof>Array of storage proofs as requested.
Implementations
Sourceimpl AccountProof
impl AccountProof
Sourcepub fn into_eip1186_response(
self,
slots: Vec<JsonStorageKey>,
) -> EIP1186AccountProofResponse
Available on crate feature eip1186 only.
pub fn into_eip1186_response( self, slots: Vec<JsonStorageKey>, ) -> EIP1186AccountProofResponse
eip1186 only.Convert into an EIP-1186 account proof response.
For non-existent accounts, this returns KECCAK_EMPTY for codeHash and
EMPTY_ROOT_HASH for storageHash, matching reth’s default behavior.
Use Self::into_eip1186_response_with to customize the behavior for
non-existent accounts (e.g. returning B256::ZERO for geth compatibility).
Sourcepub fn into_eip1186_response_with(
self,
slots: Vec<JsonStorageKey>,
zero_empty_account: bool,
) -> EIP1186AccountProofResponse
Available on crate feature eip1186 only.
pub fn into_eip1186_response_with( self, slots: Vec<JsonStorageKey>, zero_empty_account: bool, ) -> EIP1186AccountProofResponse
eip1186 only.Convert into an EIP-1186 account proof response, with optional geth-compatible zero hashes for non-existent accounts.
When zero_empty_account is true, non-existent accounts return B256::ZERO
for both codeHash and storageHash, matching geth’s behavior since v1.13.4
(go-ethereum#28357).
When false, returns KECCAK_EMPTY / EMPTY_ROOT_HASH (reth default).
Sourcepub fn from_eip1186_proof(proof: EIP1186AccountProofResponse) -> AccountProof
Available on crate feature eip1186 only.
pub fn from_eip1186_proof(proof: EIP1186AccountProofResponse) -> AccountProof
eip1186 only.Converts an
EIP1186AccountProofResponse to an
AccountProof.
This is the inverse of Self::into_eip1186_response
Sourceimpl AccountProof
impl AccountProof