Struct BranchNodeV2
pub struct BranchNodeV2 {
pub key: Nibbles,
pub stack: Vec<RlpNode>,
pub state_mask: TrieMask,
pub branch_rlp_node: Option<RlpNode>,
}Expand description
A branch node in an Ethereum Merkle Patricia Trie.
Branch node is a 17-element array consisting of 16 slots that correspond to each hexadecimal character and an additional slot for a value. We do exclude the node value since all paths have a fixed size.
This node also encompasses the possible parent extension node of a branch via the key field.
Fields
key: NibblesThe key for the branch’s parent extension. if key is empty then the branch does not have a parent extension.
stack: Vec<RlpNode>The collection of RLP encoded children.
state_mask: TrieMaskThe bitmask indicating the presence of children at the respective nibble positions
branch_rlp_node: Option<RlpNode>RlpNode encoding of the branch node. Always provided when key is not empty (i.e this
is an extension node).
Implementations
impl BranchNodeV2
impl BranchNodeV2