pub struct TrieWitness<T, H> { /* private fields */ }Expand description
State transition witness for the trie.
Implementations
Sourceimpl<T, H> TrieWitness<T, H>
impl<T, H> TrieWitness<T, H>
Sourcepub fn new(trie_cursor_factory: T, hashed_cursor_factory: H) -> Self
pub fn new(trie_cursor_factory: T, hashed_cursor_factory: H) -> Self
Creates a new witness generator.
Sourcepub fn with_trie_cursor_factory<TF>(
self,
trie_cursor_factory: TF,
) -> TrieWitness<TF, H>
pub fn with_trie_cursor_factory<TF>( self, trie_cursor_factory: TF, ) -> TrieWitness<TF, H>
Set the trie cursor factory.
Sourcepub fn with_hashed_cursor_factory<HF>(
self,
hashed_cursor_factory: HF,
) -> TrieWitness<T, HF>
pub fn with_hashed_cursor_factory<HF>( self, hashed_cursor_factory: HF, ) -> TrieWitness<T, HF>
Set the hashed cursor factory.
Sourcepub fn with_prefix_sets_mut(self, prefix_sets: TriePrefixSetsMut) -> Self
pub fn with_prefix_sets_mut(self, prefix_sets: TriePrefixSetsMut) -> Self
Set the prefix sets. They have to be mutable in order to allow extension with proof target.
Sourcepub const fn always_include_root_node(self) -> Self
pub const fn always_include_root_node(self) -> Self
Set always_include_root_node to true. Root node will be included even in empty state.
This setting is useful if the caller wants to verify the witness against the
parent state root.
Sourcepub const fn with_execution_witness_mode(
self,
mode: ExecutionWitnessMode,
) -> Self
pub const fn with_execution_witness_mode( self, mode: ExecutionWitnessMode, ) -> Self
Set the execution witness generation mode.
Sourceimpl<T, H> TrieWitness<T, H>
impl<T, H> TrieWitness<T, H>
Sourcepub fn compute(
self,
state: HashedPostState,
) -> Result<B256Map<Bytes>, TrieWitnessError>
pub fn compute( self, state: HashedPostState, ) -> Result<B256Map<Bytes>, TrieWitnessError>
Compute the state transition witness for the trie. Gather all required nodes
to apply state on top of the current trie state.
Arguments
state - state transition containing both modified and touched accounts and storage slots.